Learn R Programming

LowWAFOMSobol (version 1.1.1)

lowWAFOMSobol.dimMinMax: get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing Sequence

Description

get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing Sequence

Usage

lowWAFOMSobol.dimMinMax()

Arguments

Value

supported minimum and maximum dimension number.