lowWAFOMSobol.dimMinMax: get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing
Sequence
Description
get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing
Sequence
Usage
lowWAFOMSobol.dimMinMax()
Value
supported minimum and maximum dimension number.